@@ -17,7 +17,7 @@
  */
 
 #ifndef lint
-static const char rcsid[] = "$Id: os_unix.c,v 1.16 2000/02/03 08:52:56 skimo Exp $";
+static const char rcsid[] = "$Id: os_unix.c,v 1.20 2000/09/20 15:45:29 robs Exp $";
 #endif /* not lint */
 
 #include "fcgi_config.h"
@@ -90,6 +90,7 @@ typedef struct {
 #define AIO_RD_IX(fd) (fd * 2)
 #define AIO_WR_IX(fd) ((fd * 2) + 1)
 
+static int asyncIoInUse = FALSE;
 static int asyncIoTableSize = 16;
 static AioInfo *asyncIoTable = NULL;
 
@@ -370,7 +371,7 @@ int OS_FcgiConnect(char *bindPath)
 	resultSock = socket(AF_UNIX, SOCK_STREAM, 0);
     }
 
-    assert(resultSock >= 0);
+    ASSERT(resultSock >= 0);
     connectStatus = connect(resultSock, (struct sockaddr *) &sa.unixVariant,
                              servLen);
     if(connectStatus >= 0) {
@@ -521,6 +522,7 @@ int OS_AsyncReadStdin(void *buf, int len, OS_AsyncProc procPtr,
 {
     int index = AIO_RD_IX(STDIN_FILENO);
 
+    asyncIoInUse = TRUE;
     ASSERT(asyncIoTable[index].inUse == 0);
     asyncIoTable[index].procPtr = procPtr;
     asyncIoTable[index].clientData = clientData;
@@ -581,6 +583,7 @@ int OS_AsyncRead(int fd, int offset, void *buf, int len,
     int index = AIO_RD_IX(fd);
 
     ASSERT(asyncIoTable != NULL);
+    asyncIoInUse = TRUE;
 
     if(fd > maxFd)
         maxFd = fd;
@@ -629,6 +632,8 @@ int OS_AsyncWrite(int fd, int offset, void *buf, int len,
 {
     int index = AIO_WR_IX(fd);
 
+    asyncIoInUse = TRUE;
+
     if(fd > maxFd)
         maxFd = fd;
 
@@ -666,22 +671,26 @@ int OS_AsyncWrite(int fd, int offset, void *buf, int len,
  */
 int OS_Close(int fd)
 {
-    int index = AIO_RD_IX(fd);
+    if (asyncIoInUse) {
+        int index = AIO_RD_IX(fd);
 
-    FD_CLR(fd, &readFdSet);
-    FD_CLR(fd, &readFdSetPost);
-    if(asyncIoTable[index].inUse != 0) {
-        asyncIoTable[index].inUse = 0;
-    }
+        FD_CLR(fd, &readFdSet);
+        FD_CLR(fd, &readFdSetPost);
+        if (asyncIoTable[index].inUse != 0) {
+            asyncIoTable[index].inUse = 0;
+        }
 
-    FD_CLR(fd, &writeFdSet);
-    FD_CLR(fd, &writeFdSetPost);
-    index = AIO_WR_IX(fd);
-    if(asyncIoTable[index].inUse != 0) {
-        asyncIoTable[index].inUse = 0;
+        FD_CLR(fd, &writeFdSet);
+        FD_CLR(fd, &writeFdSetPost);
+        index = AIO_WR_IX(fd);
+        if (asyncIoTable[index].inUse != 0) {
+            asyncIoTable[index].inUse = 0;
+        }
+
+        if (maxFd == fd) {
+            maxFd--;
+        }
     }
-    if(maxFd == fd)
-        maxFd--;
     return close(fd);
 }
 
@@ -736,6 +745,7 @@ int OS_DoIo(struct timeval *tmo)
     fd_set readFdSetCpy;
     fd_set writeFdSetCpy;
 
+    asyncIoInUse = TRUE;
     FD_ZERO(&readFdSetCpy);
     FD_ZERO(&writeFdSetCpy);
 
@@ -825,6 +835,20 @@ int OS_DoIo(struct timeval *tmo)
     return 0;
 }
 
+/* 
+ * Not all systems have strdup().  
+ * @@@ autoconf should determine whether or not this is needed, but for now..
+ */
+char * str_dup(const char * str)
+{
+    char * sdup = (char *) malloc(strlen(str) + 1);
+
+    if (sdup)
+        strcpy(sdup, str);
+
+    return sdup;
+}
+
 
 /*
  *----------------------------------------------------------------------
@@ -843,29 +867,24 @@ static int ClientAddrOK(struct sockaddr_in *saPtr, const char *clientList)
 {
     int result = FALSE;
     char *clientListCopy, *cur, *next;
-    char *newString = NULL;
-    int strLen;
 
-    if(clientList == NULL || *clientList == '\0') {
+    if (clientList == NULL || *clientList == '\0') {
         return TRUE;
     }
 
-    strLen = strlen(clientList);
-    clientListCopy = (char *)malloc(strLen + 1);
-    assert(newString != NULL);
-    memcpy(newString, clientList, strLen);
-    newString[strLen] = '\000';
+    clientListCopy = str_dup(clientList);
 
-    for(cur = clientListCopy; cur != NULL; cur = next) {
+    for (cur = clientListCopy; cur != NULL; cur = next) {
         next = strchr(cur, ',');
-        if(next != NULL) {
+        if (next != NULL) {
             *next++ = '\0';
-	}
-        if(inet_addr(cur) == saPtr->sin_addr.s_addr) {
+        }
+        if (inet_addr(cur) == saPtr->sin_addr.s_addr) {
             result = TRUE;
             break;
         }
     }
+
     free(clientListCopy);
     return result;
 }
